/*
  device - VPD support routines for devices.
  
  This file is part of the Linux lsvpd package.
  
  (C) Copyright IBM Corp. 2005
  
  Maintained by  Martin Schwenke <martins@au.ibm.com>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2, or (at your option)
  any later version.
 
  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  
  $Id: lsvpd.c,v 1.3 2005/06/09 08:27:24 martins Exp $
*/

#include <stdlib.h>
#include <assert.h>

#include "lsvpd_lib_dir.h"
#include "init.h"
#include "util.h"

#include "lsvpd.h"

/********************************************************************/

#define LSVPD_DB_BUS_SUBDIR   "bus"
#define LSVPD_DB_OS_SUBDIR    "linux"
#define LSVPD_DB_MISC_SUBDIR  "misc"
#define LSVPD_DB_PROC_SUBDIR  "proc"
#define LSVPD_DB_UNAME_SUBDIR "uname"
#define LSVPD_DB_STATE_SUBDIR "state"
#define LSVPD_DB_TEMP_SUBDIR  "tmp"

const char * lsvpd_db_dir;
const char * lsvpd_db_bus_dir;
const char * lsvpd_db_os_dir;
const char * lsvpd_db_misc_dir;
const char * lsvpd_db_proc_dir;
const char * lsvpd_db_uname_dir;
const char * lsvpd_db_state_dir;
const char * lsvpd_db_temp_dir;

// FIXME: Later this will need to be exported and called via a
// pointer.  Setting the top-level directories will also not be done
// via an environment variable - it will be done like update-lsvpd-db
// currently does it.  However, all the code needs to be shifted to C
// for this to happen.

static struct {
	const char ** var;
	const char ** parent;
	const char *  subdir;
} lsvpd_vars_dirs[] = {
	{ &lsvpd_db_bus_dir,   &lsvpd_db_dir,      LSVPD_DB_BUS_SUBDIR   },
	{ &lsvpd_db_os_dir,    &lsvpd_db_dir,      LSVPD_DB_OS_SUBDIR    },
	{ &lsvpd_db_misc_dir,  &lsvpd_db_os_dir,   LSVPD_DB_MISC_SUBDIR  },
	{ &lsvpd_db_proc_dir,  &lsvpd_db_misc_dir, LSVPD_DB_PROC_SUBDIR  },
	{ &lsvpd_db_uname_dir, &lsvpd_db_misc_dir, LSVPD_DB_UNAME_SUBDIR },
	{ &lsvpd_db_state_dir, &lsvpd_db_dir,      LSVPD_DB_STATE_SUBDIR },
	{ &lsvpd_db_temp_dir,  &lsvpd_db_dir,      LSVPD_DB_TEMP_SUBDIR  },
	{ NULL,                NULL,               NULL                  },
};

static void
lsvpd_db_set_subdirs_basic (void)
{
	int i;

	lsvpd_db_dir = getenv("LSVPD_DB_DIR");
	assert(NULL != lsvpd_db_dir);

	for (i = 0; NULL != lsvpd_vars_dirs[i].var; i++) {
		*(lsvpd_vars_dirs[i].var) = \
			lsvpd_relative_filename(*(lsvpd_vars_dirs[i].parent),
						lsvpd_vars_dirs[i].subdir);
		assert(NULL != *(lsvpd_vars_dirs[i].var));
	}
}

void
lsvpd_db_mkdirs (void)
{
	int i;

	for (i = 0; NULL != lsvpd_vars_dirs[i].var; i++) {
		assert(lsvpd_mkdir(*(lsvpd_vars_dirs[i].var)));
	}
}

/********************************************************************/

static void
init(void)
{
	lsvpd_db_set_subdirs_basic();
}

INIT(init);
