#ifndef PROC_PCI_H
#define PROC_PCI_H

/*
  parse_proc_pci - Extract useful information from /proc/pci.
  
  This file is part of the Linux lsvpd package.
  
  (C) Copyright IBM Corp. 2004
  
  Maintained by  Martin Schwenke <martins@au.ibm.com>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2, or (at your option)
  any later version.
 
  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  
  $Id: proc_pci.h,v 1.3 2004/10/12 04:54:18 martins Exp $
*/
  
#include <stdbool.h>

#include "util.h"

typedef struct memlist {
	uint64_t         start;
	uint64_t         end;
	struct memlist * next;
} memlist_t;

typedef struct proc_pci_list {
	uint32_t               bus;
	uint8_t                dev;
	uint8_t                fun;
	uint16_t               class;
	uint16_t               irq;
	memlist_t *            mem;
	struct proc_pci_list * next;
} proc_pci_list_t;

extern
proc_pci_list_t *
proc_pci();

extern void
proc_pci_list_free(proc_pci_list_t * l);

extern void
proc_pci_list_fprint(FILE * f, proc_pci_list_t * l);

/* Defined in proc_pci_class.c */
extern
bool proc_pci_class(const char * this_line, proc_pci_list_t * l);

#endif
